@@ -179,7 +179,8 @@ module REXML
 			unless uri
 				@attributes["xmlns"] = prefix
 			else
-				@attributes[prefix, "xmlns"] = uri
+				prefix = "xmlns:#{prefix}" unless prefix =~ /^xmlns:/
+				@attributes[prefix] = uri
 			end
 			self
 		end
