@@ -32,12 +32,12 @@ module REXML
 				raise "no text to add" if md[0].length == 0
 				@string = md[1]
 				@string.squeeze!(" \n\t") unless respect_whitespace
-				@string = read_with_substitution(@string, ILLEGAL) unless @raw
+				@string = Node::read_with_substitution(@string, ILLEGAL) unless @raw
 			elsif arg.kind_of? String
 				super()
 				@string = arg.clone
 				@string.squeeze!(" \n\t") unless respect_whitespace
-				@string = read_with_substitution(@string) unless @raw
+				@string = Node::read_with_substitution(@string) unless @raw
 			elsif arg.kind_of? Text
 				super()
 				@string = arg.string
@@ -79,7 +79,11 @@ module REXML
 		end
 
 		def Text.parse_stream source, listener
-			listener.text source.match(PATTERN, true)[0]
+			md = source.match(PATTERN, true)
+			raise "no text to add" if md[0].length == 0
+			string = md[1]
+			string = Node::read_with_substitution(string, ILLEGAL)
+			listener.text string
 		end
 	end
- end
+end
