@@ -3,6 +3,7 @@ require 'rexml/namespace'
 module REXML
 	class XPathParser
 		LITERAL		= /^'([^']*)'|"([^"]*)"/u
+		DEBUG=true
 
 		def initialize
 			@EQ_PROC = proc do |a,o,b|
@@ -221,7 +222,7 @@ module REXML
 		def PathExpr path, nodeset
 			#puts "PathExpr( #{path}, #{puta nodeset} )" if DEBUG
 			p,n = FilterExpr path, nodeset
-			#puts "After FilterExpr p is '#{p}' and n is #{puta n}" if DEBUG
+			#puts "After FilterExpr p is '#{p}' and n is #{puta n}" #if DEBUG
 			return [p,n] if p.size == 0
 			# p is now '/' '/'? RelativeLocationPath
 			if p =~ /^\/\/?/
@@ -241,7 +242,7 @@ module REXML
 		#| PrimaryExpr
 		def FilterExpr path, nodeset
 			path, results = PrimaryExpr(path, nodeset)
-			#puts "Path is now '#{path}', results are #{puta results}" if DEBUG
+			#puts "Path is now '#{path}', results are #{puta results}" #if DEBUG
 			path, results = Predicate(path, results) if path[0] == ?[
 			[path, results]
 		end
@@ -298,7 +299,7 @@ module REXML
 				#puts "CURARGS IS ::: #{args.size}" if DEBUG
 
 				nodeset.each_index do |index|
-					#puts "1) Calling #{funcname}(#{args.join ', '}) with #{args.size} args" if DEBUG
+					#puts "1) Calling #{funcname}(#{args.join ', '}) with #{args.size} args" #if DEBUG
 					results << Functions.send( funcname, *args )
 				end
 			else
@@ -549,6 +550,7 @@ module REXML
 					r = r[0] if r.kind_of? Array
 					if r.to_s =~ /^\d+$/
 						r = r.to_i
+						#puts "COMPARING #{r} to #{ind}"
 						r = (r == ind)
 					end
 					#puts "PREDICATE ON NODE #{node.name if node.kind_of? Element}" if DEBUG
